#
# spec file for package libesmtp
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libesmtp
Version:        1.0.6
Release:        lp152.4.3.1
Summary:        A Library for Posting Electronic Mail
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.stafford.uklinux.net/libesmtp/
Source0:        %{name}-%{version}.tar.bz2
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/Packaging/Patches
Patch0:         libesmtp-removedecls.diff
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/Packaging/Patches
Patch1:         libesmtp-1.0.4-bloat.patch
# PATCH-FIX-UPSTREAM libesmtp-tlsv12.patch crrodriguez@opensuse.org -- All TLS clients must support and use the highest TLS version available
Patch2:         libesmtp-tlsv12.patch
# PATCH-FIX-UPSTREAM libesmtp-fix-cve-2019-19977.patch yfjiang@suse.com bsc#1189097 bsc#1160462 - Fix stack-based buffer over-read in ntlm/ntlmstruct.c.
Patch3:         libesmtp-fix-cve-2019-19977.patch
BuildRequires:  openssl-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libESMTP is a library to manage posting (or submission of) electronic
mail using SMTP to a preconfigured Mail Transport Agent (MTA) such as
Exim. It may be used as part of a Mail User Agent (MUA) or another
program that must be able to post electronic mail but where mail
functionality is not that program's primary purpose.

%package devel
Summary:        A Library for Posting Electronic Mail
Group:          Development/Libraries/C and C++
Requires:       libesmtp = %{version}

%description devel
libESMTP is a library to manage posting (or submission of) electronic
mail using SMTP to a preconfigured Mail Transport Agent (MTA) such as
Exim. It may be used as part of a Mail User Agent (MUA) or another
program that must be able to post electronic mail but where mail
functionality is not that program's primary purpose.

%prep
%setup -q
%patch0
%patch1
%patch2 -p1
%patch3 -p1

%build
%configure --disable-static --with-pic \
		--enable-ntlm 		\
		--enable-etrn 		\
		--disable-isoc
%{__make} %{?_smp_mflags}

%install
%makeinstall
#uses dlsym not ltdl ..useless files
rm -rf %{buildroot}%{_libdir}/esmtp-plugins/*a
rm -rf %{buildroot}%{_libdir}/*a

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README AUTHORS ChangeLog COPYING
%dir %{_libdir}/esmtp-plugins
%{_libdir}/esmtp-plugins/*so*
%{_libdir}/libesmtp.*so.*

%files devel
%defattr(-,root,root)
%{_bindir}/libesmtp-config
%{_includedir}/*.h
%{_libdir}/libesmtp.*so

%changelog
* Fri Aug  6 2021 Yifan Jiang <yfjiang@suse.com>
- Add libesmtp-fix-cve-2019-19977.patch: Fix stack-based buffer
  over-read in ntlm/ntlmstruct.c (bsc#1160462 bsc#1189097).
* Fri Sep 30 2016 crrodriguez@opensuse.org
- Add libesmtp-tlsv12.patch: All TLS clients must support and use
  the highest TLS version available if possible not only TLS 1.0.
  Patch sent to upstream long time ago, no response. website
  has also vanished from the internet (bsc#1005909).
- Pass --disable-isoc to configure, pick the compiler's default C
  standard mode (currently gnu11).
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Tue Aug 10 2010 dimstar@opensuse.org
- Update to version 1.0.6:
  + Each component matched by match-domain() is either a single
    '*' which matches anything or a case-insensitive comparison
    with a string of alphanumeric characters or a '-'.
- Changes from version 1.0.5:
  + The Gmail server reports enhanced status codes but then fails
    to provide them in some cases. The parser is now tolerant of
    this but warns the application using a new event flag
    SMTP_EV_SYNTAXWARNING that it is progressing despite the syntax
    error.
  + Fixed bug where To, Cc, Bcc etc. accepted only single values
    instead of a list.
  + Fix reversed comparison on the return value of gettimeofday().
- Drop upstream fixed patches libesmtp-1.0.4-multiple-cc.patch and
  libestmp-commonname.diff.
- Cleaned spec file using spec-cleaner.
* Wed Apr 28 2010 freitag@novell.com
- Add libestmp-commonname.diff to do stricter check on commonName
  bnc#585393.
* Wed Aug  6 2008 bwalle@suse.de
- allow multiple calls of smtp_set_header() for Cc and Bcc headers
- disable lwres because we don't want to have a daemon (the lwresd)
  running just for address resolution
* Tue Sep  4 2007 mrueckert@suse.de
- remove postfix from the buildrequires
- do not package generic INSTALL file
* Tue Sep  4 2007 crrodriguez@suse.de
- fix #307257 missing requires of the libesmtp-devel package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 lmichnovic@suse.cz
- Updated to version 1.0.4
- enabled support for lwres: lwres_includedir.patch; bind-devel added into NFB
- enabled support for ntlm, etrn
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Mon Sep 26 2005 mls@suse.de
- move .so symlink into devel package
- make devel package require base package
* Sun May  8 2005 mmj@suse.de
- Don't declare things we have for sure on linux
* Fri Mar 26 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 1.0.2.
* Wed Jul 30 2003 hhetter@suse.de
- initial SuSE package
